@@ -1,5 +1,5 @@
-from ..argument import AnyArguments, IArguments, ValueArgument
 from ..constants import default_discovery_port
+from ..util.argument import AnyArguments, create_value_argument, IArguments
 from ..util.Lazy import Lazy
 
 
@@ -8,4 +8,4 @@ class DiscoveryCommonArguments(IArguments):
         self.port = Lazy(lambda store: default_discovery_port)
 
     def get_arguments(self) -> AnyArguments:
-        return [ValueArgument(self.port, '--discovery-port', int, 'Discovery broadcast port.')]
+        return [create_value_argument(self.port, '--discovery-port', int, 'Discovery broadcast port.')]
